#!/bin/sh
#
# Converts a 800x600 image in to a splash sceen image suitable
#
# The outout image is raw data BGRA file. This format allows stamping straight in to the frame buffer
# by, for example, dd if=splash.fb of=/dev/fb0

# check the convert command is installed (comes from ImageMagick)
command -v /usr/bin/convert >/dev/null 2>&1 || { echo "/usr/bin/convert needs to be installed" >&2; exit 1; }

# convert to the png to an rgba image of the right format
# Needs to be pixel colour components need to be in the order Blue-Green-Red-Alpha, 8 bits each
/usr/bin/convert -size 800x600 -depth 8 updating.png -separate -swap 0,2 -combine updating.rgba
/usr/bin/convert -size 800x600 -depth 8 success.png -separate -swap 0,2 -combine success.rgba
/usr/bin/convert -size 800x600 -depth 8 failed.png -separate -swap 0,2 -combine failed.rgba
if [ $? -eq 0 ]; then
    # convert name to the one I'm happier with
    mv updating.rgba updating.fb
    mv success.rgba success.fb
    mv failed.rgba failed.fb
else
    echo "Failed to convert splash.png to splash.fb"
fi

echo done

