#!/bin/sh
# Maintain the status of the USB ports and report to the PipeUI app
#
# Params:
# 1 Action
# 2 kernel device name (e.g. sda1)
# 3 Port/Location (e.g. USB0)
#    USB0 --> the top most USB slot on the front panel
#    USB1 --> the middle USB slot on the front panel
#    USB2 --> the bottom USB slot on the front panel
#    SD   --> the SD Card mounted on the front panel
#    USD  --> the micro SD Card mounted internally
#    SSD  --> the internal solid state drive
#    LOCAL--> /home/root/survey

PATH=$PATH:/sbin
LOGFILE=/opt/pel/log/portmount
COMMENT=portmount
FIFO=fifo
MNTPATH=/media/$2
DEVPATH=/dev/$2
PORTNAME=UNKNOWN

timestamp() {
	date +"%T"
}

echo "$(timestamp): $COMMENT: Start" >> $LOGFILE

echo "$(timestamp): $COMMENT: $1 drive, device is $2" >> $LOGFILE

if [ "$1" = "remove" ]; then
	# check if device is mounted
	/bin/mountpoint -q $MNTPATH 2> /dev/null
	if [ $? -eq 0 ]; then
		echo "$(timestamp): $COMMENT: $MNTPATH is mounted" >> $LOGFILE
		/bin/sh /opt/pel/bin/myecho.sh $FIFO UMT $MNTPATH
		echo "$(timestamp): $COMMENT: Attempt umount $MNTPATH" >> $LOGFILE
		/bin/umount -l $MNTPATH
		if [ $? -eq 0 ]; then
			echo "$(timestamp): $COMMENT: Remove $MNTPATH" >> $LOGFILE
			/bin/rmdir $MNTPATH
		else
			echo "$(timestamp): $COMMENT: umount FAILED" >> $LOGFILE
		fi
	else
		echo "$(timestamp): $COMMENT: $MNTPATH not a mountpoint. Returns $? " >> $LOGFILE
	fi
elif [ "$1" = "add_ntfs" -o "$1" = "add_fat" ]; then
	# check if device has been mounted by udev
	/bin/mountpoint -q $MNTPATH 2> /dev/null
	if [ $? -eq 0 ]; then
		RO=`egrep -c $2'.*\sro[\s,]' /proc/mounts`
		if [ $RO -eq 0 ]; then

		echo "$(timestamp): $COMMENT: $MNTPATH is mounted" >> $LOGFILE
		ADDRESS=`/sbin/udevadm info --query=path --name=/dev/$2 | awk 'BEGIN { FS = "/" } ; { print $8 }'`
		echo "$(timestamp): $COMMENT: udevadm returns $ADDRESS" >> $LOGFILE
		case "$ADDRESS" in
		"1-1.1") PORTNAME=USB1
			;;
		"1-1.2") PORTNAME=USB2
			;;
		"1-1.3") PORTNAME=USB3
			;;
		"1-1.4") PORTNAME=USB0
			;;
	#	"mmc?:"*)PORTNAME=SD
	#		;;
		"mmc0:"*)PORTNAME=LOCAL
			;;
		"mmc1:"*)PORTNAME=USD
			;;
		"0:0:"*) PORTNAME=SSD
			;;
		*) PORTNAME=UNKNOWN
			;;
		esac

		echo "$(timestamp): $COMMENT: $1 drive, device is $2 at $PORTNAME" >> $LOGFILE

		/bin/sh /opt/pel/bin/myecho.sh $FIFO MNT $PORTNAME $MNTPATH

		else
			echo "$(timestamp): $COMMENT: $DEVPATH is mounted READONLY at $MNTPATH" >> $LOGFILE
		fi
	else
		echo "$(timestamp): $COMMENT: mount FAILED" >> $LOGFILE
	fi
else
	echo "$(timestamp): $COMMENT: Unknown action: $1" >> $LOGFILE
fi

echo "$(timestamp): $COMMENT: Done" >> $LOGFILE


