#!/bin/sh
# Update the status of the storage media and report to the PipeUI app
#
# Params: None
# 
# Port/Location (e.g. USB0)
#    USB0 --> the top most USB slot on the front panel
#    USB1 --> the middle USB slot on the front panel
#    USB2 --> the bottom USB slot on the front panel
#    SD   --> the SD Card mounted on the front panel
#    USD  --> the micro SD Card mounted internally
#    SSD  --> the internal solid state drive
#    LOCAL--> /home/root/survey

PATH=$PATH:/sbin
LOGFILE=/opt/pel/log/portmount
COMMENT=updatemounts
FIFO=fifo
MNTPATH=UNKNOWN
DEVPATH=UNKNOWN
PORTNAME=UNKNOWN

timestamp() {
	date +"%T"
}

echo "$(timestamp): $COMMENT: Start" >> $LOGFILE


#mount | egrep 'sys|var' | while read -r line; do echo "RR $line RR"; done
#echo "$(timestamp): $COMMENT: $1 drive, device is $2" >> $LOGFILE

#elif [ $1 == "add_ntfs" -o $1 == "add_fat" ]; then
	# check if device has been mounted by udev
#	/bin/mountpoint -q $MNTPATH 2> /dev/null
#	if [ $? -eq 0 ]; then

#echo Script started >> /var/log/updatemounts

#mount | egrep '/dev/sd|/dev/mmcblk1p' | while read -r line; do
#mount | egrep '/dev/sd|/dev/mmcblk0p|/dev/mmcblk1p' | while read -r line; do

# /dev/sd - Any external USB device
# /dev/mmcblk0p2 - the ext4 partition of the internal emmc storage
# /dev/mmcblk1 - the interanl uSD card slot
mount | egrep '/dev/sd|/dev/mmcblk0p2|/dev/mmcblk1' | while read -r line; do

	DEVPATH=`echo $line | awk '{ print $1 }'`
	MNTPATH=`echo $line | awk '{ print $3 }'`

	RO=`echo $line | grep -c '[(,]ro[),]'`

	if [ $RO -eq 0 ]; then

		echo "$(timestamp): $COMMENT: $DEVPATH is mounted at $MNTPATH" >> $LOGFILE

		ADDRESS=`/sbin/udevadm info --query=path --name=$DEVPATH | awk 'BEGIN { FS = "/" } ; { print $8 }'`
		echo "$(timestamp): $COMMENT: udevadm returns $ADDRESS" >> $LOGFILE
		case "$ADDRESS" in
		"1-1.1") PORTNAME=USB1
			;;
		"1-1.2") PORTNAME=USB2
			;;
		"1-1.3") PORTNAME=USB3
			;;
		"1-1.4") PORTNAME=USB0
			;;
	#	"mmc?:"*)PORTNAME=SD
	#		;;
		"mmc0:"*)PORTNAME=LOCAL
			;;
		"mmc1:"*)PORTNAME=USD
			;;
		"0:0:"*) PORTNAME=SSD
			;;
		*) PORTNAME=UNKNOWN
			;;
		esac

		echo "$(timestamp): $COMMENT: Device is $DEVPATH at $PORTNAME" >> $LOGFILE

		/bin/sh /opt/pel/bin/myecho.sh $FIFO MNT $PORTNAME $MNTPATH
	else
		echo "$(timestamp): $COMMENT: $DEVPATH is mounted READONLY at $MNTPATH" >> $LOGFILE
	fi
done

echo "$(timestamp): $COMMENT: Done" >> $LOGFILE


