#!/bin/sh
# Update the main application


directory="/opt/pel/bin"
lib_dir="/opt/pel/lib"
boot_dir="/boot"
mod_dir="/lib/modules"
pel_dir="/opt/pel"
upgradedir="/opt/pel/upgrade"
SCRIPT=$(readlink -f "$0")
DIR=$(dirname "$SCRIPT")
supplier=""
module=""
imagePath="/home/pi/upgradeImage"

# check if actually for a Maxprobe-Pi, if target is a raspberry pi
raspberry="$(cat /proc/device-tree/model | grep "Raspberry")"
if [ -z "$raspberry" ]
then
	echo "This is not the correct system for this upgrade"
    exit 0
fi

if [ -f $DIR/SPARTAN ]
then
	echo "supplier set to Spartan" 
	cp $DIR/spartan_splash.png /opt/pel/bin/splash_start.png
else
	echo "supplier set to Scanprobe" 
	cp $DIR/scanprobe_splash.png /opt/pel/bin/splash_start.png	
fi

chmod 777 /opt/pel/bin/splash.rgba

# get language
if [ -f $directory/upgrade_language.txt ]
then
	echo "Language File Found!"
	language=$(cat $directory/upgrade_language.txt)
else
	language="en-GB"
fi

echo "$language"	
# Kill PipeUI
echo "killing PipeUI"
killall PipeUI
killall PE2504
echo "Waiting 5 seconds to complete"
sleep 5
sudo /opt/pel/bin/PE2504 $DIR/pics/updating_$language.png &
echo "Finished waiting"
sleep 1

rm -rf /home/root/scanprobe
zerofiles=$(find -size 0 -type f | wc -l) #check number of files with size 0bytes

if [ ! -s $DIR/PipeUI ]; then
	echo "File isn't executable"
	echo $DIR/pics/failed_$language.png > $imagePath
else
	# Rename the application for copying
	#mv $DIR/PipeUI $DIR/PipeUI.new
	#echo $?

	# Copy new executable to the bin directory
	echo "Copying new application"
	cp $DIR/PipeUI $directory/PipeUI.new
	echo $?

	sleep 1

	# Remove old application
	echo "Removing old application"
	rm -rf $directory/PipeUI
	echo $?

	# Rename new application to match required name
	echo "Renaming the new application"
	mv $directory/PipeUI.new $directory/PipeUI
	echo $?

	sleep 1

	echo "New application successfully copied"
	echo "Setting Permissions"

	chmod +x $directory/PipeUI
	echo $?

	echo "Removing Superfluous Files"
	rm -rf $directory/PipeUI.new
	echo $?
	
	if [ -s $DIR/libs/install_libs.sh ]; then
	echo "Updating libraries"

	/bin/sh $DIR/libs/install_libs.sh

	echo "Updating libraries complete!"
	else
		echo "No new libraries"
	fi

	if [ -s $DIR/PE2414/install.sh ]; then
		echo "Updating filesystem"

		/bin/sh $DIR/PE2414/install.sh

		echo "Updating filesystem complete!"
	else
		echo "No new file system"
	fi

	if [ -s $DIR/PE1618/install.sh ]; then
		echo "Updating help files"

		/bin/sh $DIR/PE1618/install.sh

		echo "Updating help files complete!"
	else
		echo "No new help files"
	fi

	if [ -d $DIR/WinCan ]; then
		echo "Copying Catalogues"

		if [ ! -d /opt/pel/etc ]; then
			mkdir /opt/pel/etc
		fi
		
		cp -r $DIR/WinCan /opt/pel/etc/

		echo "Updating Catalogues Complete"
	else
		echo "No new catalogues!"
	fi
	
	if [ -s $DIR/splash.png ]; then
		echo "Updating splash file"

		/bin/sh $DIR/makesplash.sh

		mv $DIR/splash.png $DIR/splash.png.new
		mv $DIR/splash.fb $DIR/splash.fb.new
	
		echo "Copying new splash file"
		cp $DIR/splash.png.new $pel_dir
		cp $DIR/splash.fb.new $pel_dir

		sleep 1

		echo "Removing splash file"
		rm -rf $pel_dir/splash.png
		rm -rf $pel_dir/splash.fb

		echo "Renaming new splash file"
		mv $pel_dir/splash.png.new $pel_dir/splash.png
		mv $pel_dir/splash.fb.new $pel_dir/splash.fb

		sleep 1

		echo "New splash file copied"

		echo "Removing superfluous files"
		rm -rf $pel_dir/splash.png.new
		rm -rf $pel_dir/splash.fb.new
		mv $DIR/splash.png.new $DIR/splash.png
	else
		echo "No new splash file"
	fi

	if [ -s $DIR/$supplier/$module ]; then
		echo "Updating Modules"

		sleep 1

		echo "Removing old modules"
		rm -rf $mod_dir/3.0.35-pe1588*
		rm -rf $mod_dir/3.0.35pe1588*
		
		echo "Unpacking tarball"
		tar -xjf $DIR/$supplier/$module -C $mod_dir

		echo "Modules Updated"

	else
		echo "No new Modules file"
	fi	

	echo "Done"
	echo $DIR/pics/success_$language.png > $imagePath
fi

# disable service
sudo systemctl disable dhcpcd.service

/bin/sh $DIR/PE2414/clear_cache.sh

echo "Press Power Button To Reboot System!"

